==> haskell-crypto-pubkey-types-0.4.3-411-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-EfED19Nn0fOIV1W1ym94CU
key:                  crypto-pubkey-types-0.4.3-EfED19Nn0fOIV1W1ym94CU
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  72952e8d026248733ee6e33a75b2b563
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-EfED19Nn0fOIV1W1ym94CU
depends:
    asn1-encoding-0.9.6-4264oq0sIsv6VCR8zfUiAI
    asn1-types-0.3.4-F92MSl1lYFNJVJ60pcmj2r base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-412-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-3ukFZHgNEEyJwx5LHCC7Vb
key:                  crypto-pubkey-types-0.4.3-3ukFZHgNEEyJwx5LHCC7Vb
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  c8b1959f7be3c65ead094fb40c9aa65c
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-pubkey-types
hs-libraries:         HScrypto-pubkey-types-0.4.3-3ukFZHgNEEyJwx5LHCC7Vb
depends:
    asn1-encoding-0.9.6-ET1vn5gVP3QGemLlGFYiaH
    asn1-types-0.3.4-8wxeS7sugqrFE7SbloeBbr base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
